#[repr(u8)]pub enum Frc {
Frc0 = 0,
Frc1 = 1,
Frc2 = 2,
Frc3 = 3,
Frc4 = 4,
Frc5 = 5,
Frc6 = 6,
Frc7 = 7,
}Expand description
Functional Road Class. The functional road class (FRC) of a line is a road classification based on the importance of the road represented by the line.
Variants
Frc0 = 0
Main road, highest importance
Frc1 = 1
First class road.
Frc2 = 2
Second class road.
Frc3 = 3
Third class road.
Frc4 = 4
Fourth class road.
Frc5 = 5
Fifth class road.
Frc6 = 6
Sixth class road.
Frc7 = 7
Other class road, lowest importance
Implementations