#[repr(u8)]pub enum Orientation {
Unknown = 0,
Forward = 1,
Backward = 2,
Both = 3,
}Expand description
The orientation information (ORI) describes the relationship between the point of interest and the direction of a referenced line.
Variants
Unknown = 0
Point has no sense of orientation, or determination of orientation is not applicable.
Forward = 1
Point has orientation from first LRP towards second LRP.
Backward = 2
Point has orientation from second LRP towards first LRP.
Both = 3
Point has orientation in both directions