pub struct Bearing(/* private fields */);Expand description
The bearing describes the angle between the true North and the road. The physical data format defines the bearing field as an integer value between 0 and 360 whereby “0” is included and “360” is excluded from that range.
Implementations