pub struct Line {
pub points: Vec<Point>,
pub offsets: Offsets,
}Expand description
A line location reference describes a path within a map and consists of location reference point(s), a last location reference point and offset data. There must be at least one location reference point and exactly one last location reference point. The offset field is optional.
Fields
points: Vec<Point>offsets: OffsetsTrait Implementations
impl StructuralPartialEq for Line