PointAlongLine

Struct PointAlongLine 

pub struct PointAlongLine {
    pub points: [Point; 2],
    pub offset: Offset,
    pub orientation: Orientation,
    pub side: SideOfRoad,
}
Point along line is a point location which is defined by a line and an offset value. The line will be referenced by two location reference points and the concrete position on that line is referenced using the positive offset. Additionally information about the side of the road where the point is located and the orientation with respect to the direction of the line can be added.

Fields

points: [Point; 2]offset: Offsetorientation: Orientationside: SideOfRoad