pub struct PointAlongLine {
pub points: [Point; 2],
pub offset: Offset,
pub orientation: Orientation,
pub side: SideOfRoad,
}Expand description
Point along line is a point location which is defined by a line and an offset value. The line will be referenced by two location reference points and the concrete position on that line is referenced using the positive offset. Additionally information about the side of the road where the point is located and the orientation with respect to the direction of the line can be added.
Fields
points: [Point; 2]offset: Offsetorientation: Orientationside: SideOfRoadTrait Implementations
Sourceimpl Clone for PointAlongLine
impl Clone for PointAlongLine
Sourcefn clone(&self) -> PointAlongLine
fn clone(&self) -> PointAlongLine
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PointAlongLine
impl Debug for PointAlongLine
Sourceimpl Default for PointAlongLine
impl Default for PointAlongLine
Sourcefn default() -> PointAlongLine
fn default() -> PointAlongLine
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for PointAlongLine
impl PartialEq for PointAlongLine
impl StructuralPartialEq for PointAlongLine